@@ -12,6 +12,7 @@
  * for more details.
  */
 
+#include <QLoggingCategory>
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QNetworkProxy>
@@ -20,18 +21,21 @@
 #include <QNetworkCookie>
 #include <QNetworkCookieJar>
 #include <QNetworkConfiguration>
+#include <QUuid>
+#include <QLibraryInfo>
 
 #include "cookiejar.h"
 #include "accessmanager.h"
-#include "utility.h"
+#include "common/utility.h"
 
-namespace OCC
-{
+namespace OCC {
 
-AccessManager::AccessManager(QObject* parent)
-    : QNetworkAccessManager (parent)
+Q_LOGGING_CATEGORY(lcAccessManager, "sync.accessmanager", QtInfoMsg)
+
+AccessManager::AccessManager(QObject *parent)
+    : QNetworkAccessManager(parent)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0) && defined(Q_OS_MAC)
+#if defined(Q_OS_MAC)
     // FIXME Workaround http://stackoverflow.com/a/15707366/2941 https://bugreports.qt-project.org/browse/QTBUG-30434
     QNetworkProxy proxy = this->proxy();
     proxy.setHostName(" ");
@@ -45,11 +49,11 @@ AccessManager::AccessManager(QObject* parent)
     setCookieJar(new CookieJar);
 }
 
-void AccessManager::setRawCookie(const QByteArray &rawCookie, const  QUrl &url)
+void AccessManager::setRawCookie(const QByteArray &rawCookie, const QUrl &url)
 {
     QNetworkCookie cookie(rawCookie.left(rawCookie.indexOf('=')),
-                          rawCookie.mid(rawCookie.indexOf('=')+1));
-    qDebug() << Q_FUNC_INFO << cookie.name() << cookie.value();
+        rawCookie.mid(rawCookie.indexOf('=') + 1));
+    qCDebug(lcAccessManager) << cookie.name() << cookie.value();
     QList<QNetworkCookie> cookieList;
     cookieList.append(cookie);
 
@@ -57,7 +61,14 @@ void AccessManager::setRawCookie(const QByteArray &rawCookie, const  QUrl &url)
     jar->setCookiesFromUrl(cookieList, url);
 }
 
-QNetworkReply* AccessManager::createRequest(QNetworkAccessManager::Operation op, const QNetworkRequest& request, QIODevice* outgoingData)
+static QByteArray generateRequestId()
+{
+    // Use a UUID with the starting and ending curly brace removed.
+    auto uuid = QUuid::createUuid().toByteArray();
+    return uuid.mid(1, uuid.size() - 2);
+}
+
+QNetworkReply *AccessManager::createRequest(QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *outgoingData)
 {
     QNetworkRequest newRequest(request);
 
@@ -75,8 +86,30 @@ QNetworkReply* AccessManager::createRequest(QNetworkAccessManager::Operation op,
     // For PROPFIND (assumed to be a WebDAV op), set xml/utf8 as content type/encoding
     // This needs extension
     if (verb == "PROPFIND") {
-        newRequest.setHeader( QNetworkRequest::ContentTypeHeader, QLatin1String("text/xml; charset=utf-8"));
+        newRequest.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("text/xml; charset=utf-8"));
     }
+
+    // Generate a new request id
+    QByteArray requestId = generateRequestId();
+    qInfo(lcAccessManager) << op << verb << newRequest.url().toString() << "has X-Request-ID" << requestId;
+    newRequest.setRawHeader("X-Request-ID", requestId);
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 4)
+    // only enable HTTP2 with Qt 5.9.4 because old Qt have too many bugs (e.g. QTBUG-64359 is fixed in >= Qt 5.9.4)
+    if (newRequest.url().scheme() == "https") { // Not for "http": QTBUG-61397
+        // Qt 5.12.4 fixed QTBUG-73947 - http2 should be usable after that
+        bool http2Allowed = QLibraryInfo::version() >= QVersionNumber(5, 12, 4);
+
+        static auto http2EnabledEnv = qgetenv("OWNCLOUD_HTTP2_ENABLED");
+        if (http2EnabledEnv == "1")
+            http2Allowed = true;
+        if (http2EnabledEnv == "0")
+            http2Allowed = false;
+
+        newRequest.setAttribute(QNetworkRequest::HTTP2AllowedAttribute, http2Allowed);
+    }
+#endif
+
     return QNetworkAccessManager::createRequest(op, newRequest, outgoingData);
 }
 
